@@ -60,14 +60,18 @@ fftrees_ffttowords <- function(x = NULL,
   n_trees <- x$trees$n
 
   # tree_df <- x$trees$definition  # df (from object x)
-  tree_df <- get_fft_definitions(x = x)  # df (using helper fn)
+  tree_df <- get_fft_df(x = x)  # df (using helper fn)
   # print(tree_df)  # 4debugging
 
   # Provide user feedback: ----
 
-  if (!x$params$quiet) {
-    msg <- paste0("Aiming to express FFTs in words:\n")
-    cat(u_f_ini(msg))
+  if (!x$params$quiet$ini) {
+
+    # msg <- paste0("Aiming to express FFTs in words:\n")
+    # cat(u_f_ini(msg))
+
+    cli::cli_alert("Express {x$trees$n} FFT{?s} in words:", class = "alert-start")
+
   }
 
 
@@ -75,7 +79,7 @@ fftrees_ffttowords <- function(x = NULL,
 
   x$trees$inwords <- vector("list", length = n_trees)
 
-  exit_word <- tolower(exit_word(mydata))  # either 'train':'decide' or 'test':'predict'
+  get_exit_word <- tolower(get_exit_word(mydata))  # either 'train':'decide' or 'test':'predict'
 
 
 
@@ -143,16 +147,18 @@ fftrees_ffttowords <- function(x = NULL,
 
       # 1. Non-final nodes: ----
 
-      if (exit_i %in% c("0", "1")) {
+      non_final_exit_types <- as.character(exit_types[1:2])
 
-        # a. Node with positive exit:
-        if (exit_i == "1") {
+      if (exit_i %in% non_final_exit_types) {
+
+        # a. Node with positive exit ("1" / TRUE / signal / right):
+        if (exit_i == non_final_exit_types[2]) {
 
           if (class_v[i] %in% c("c", "l")) {
 
             sentence_i <- paste0(
               "If ", cue_v[i], " ", direction_v[i], " {", threshold_v[i],
-              "}, ", exit_word, " ", decision.labels[2], ".")
+              "}, ", get_exit_word, " ", decision.labels[2], ".")
 
           }
 
@@ -163,16 +169,16 @@ fftrees_ffttowords <- function(x = NULL,
 
             sentence_i <- paste0(
               "If ", cue_v[i], " ", direction_v[i], " ", threshold_i,
-              ", ", exit_word, " ", decision.labels[2], ".")
+              ", ", get_exit_word, " ", decision.labels[2], ".")
           }
 
         } # a. Node with positive exit.
 
 
-        # b. Node with negative exit:
-        if (exit_i == "0") {
+        # b. Node with negative exit ("0" / FALSE / noise / left):
+        if (exit_i == non_final_exit_types[1]) {
 
-          # Negate the direction:
+          # Negate the exit / cue threshold direction:
           direction_i <- switch(direction_v[i],
                                 "=" = "!=",
                                 "!=" = "=",
@@ -186,7 +192,7 @@ fftrees_ffttowords <- function(x = NULL,
 
             sentence_i <- paste0(
               "If ", cue_v[i], " ", direction_i, " {", threshold_v[i], "}, ",
-              exit_word, " ", decision.labels[1], ".")
+              get_exit_word, " ", decision.labels[1], ".")
 
           }
 
@@ -197,7 +203,7 @@ fftrees_ffttowords <- function(x = NULL,
 
             sentence_i <- paste0(
               "If ", cue_v[i], " ", direction_i, " ", threshold_i,
-              ", ", exit_word, " ", decision.labels[1], ".")
+              ", ", get_exit_word, " ", decision.labels[1], ".")
 
           }
 
@@ -210,7 +216,8 @@ fftrees_ffttowords <- function(x = NULL,
 
       # 2. Final nodes: ----
 
-      if (exit_i %in% c(".5", "0.5", "0.50", "0.500")) {
+      # Final exit type (0.5 / both / final):
+      if (exit_i == as.character(exit_types[3]))  {
 
         direction_pos_i <- direction_v[i]
 
@@ -240,11 +247,11 @@ fftrees_ffttowords <- function(x = NULL,
           # Positive directions (TRUE cases first):
           sentence_i_1 <- paste0(
             "If ", cue_v[i], " ", direction_pos_i, " {", threshold_v[i], "}, ",
-            exit_word, " ", decision.labels[2], "") # TRUE cases/right
+            get_exit_word, " ", decision.labels[2], "") # 1 / TRUE / signal / right cases
 
           sentence_i_2 <- paste0(
-            ", otherwise, ", exit_word, " ",
-            decision.labels[1], ".") # FALSE cases/left
+            ", otherwise, ", get_exit_word, " ",
+            decision.labels[1], ".") # 0 / FALSE / noise / left cases
 
         }
 
@@ -265,11 +272,11 @@ fftrees_ffttowords <- function(x = NULL,
           # Positive directions (TRUE cases first):
           sentence_i_1 <- paste0(
             "If ", cue_v[i], " ", direction_pos_i, " ", threshold_v[i],
-            ", ", exit_word, " ", decision.labels[2], "") # TRUE cases/right
+            ", ", get_exit_word, " ", decision.labels[2], "") # 1 / TRUE / signal / right cases
 
           sentence_i_2 <- paste0(
-            ", otherwise, ", exit_word, " ",
-            decision.labels[1], ".") # FALSE cases/left
+            ", otherwise, ", get_exit_word, " ",
+            decision.labels[1], ".") # 0 / FALSE / noise / left cases
 
         }
 
@@ -293,9 +300,13 @@ fftrees_ffttowords <- function(x = NULL,
 
   # Provide user feedback: ----
 
-  if (!x$params$quiet) {
-    msg <- paste0("Successfully expressed FFTs in words.\n")
-    cat(u_f_fin(msg))
+  if (!x$params$quiet$fin) {
+
+    # msg <- paste0("Successfully expressed FFTs in words.\n")
+    # cat(u_f_fin(msg))
+
+    cli::cli_alert_success("Expressed {x$trees$n} FFT{?s} in words.")
+
   }
 
 
