@@ -11,22 +11,22 @@ knitr::opts_chunk$set(collapse = FALSE,
                       fig.align = 'center', 
                       fig.height = 6.0, 
                       fig.width  = 6.5, 
-                      out.width = "600px")
+                      out.width = "580px")
 
 ## ----pkgs, echo = FALSE, message = FALSE, results = 'hide'--------------------
 library(FFTrees)
 
 ## ----install-pkg, eval = FALSE------------------------------------------------
-#  # Install the package from CRAN:
-#  install.packages("FFTrees")
+# # Install the package from CRAN:
+# install.packages("FFTrees")
 
 ## ----load-pkg-2, eval = TRUE, message = TRUE----------------------------------
 # Load the package:
 library(FFTrees)
 
 ## ----load-guide, eval = FALSE-------------------------------------------------
-#  # Open the main package guide:
-#  FFTrees.guide()
+# # Open the main package guide:
+# FFTrees.guide()
 
 ## ----fft-create, message = FALSE----------------------------------------------
 # Create an FFTrees object:
@@ -42,7 +42,7 @@ heart.fft <- FFTrees(formula = diagnosis ~ .,           # Criterion and (all) pr
 heart.fft
 
 ## ----fft-confusion-table, out.width="50%", echo = FALSE, fig.cap = "**Table 1**: A 2x2 confusion table illustrating the types of frequency counts for 4 possible outcomes."----
-knitr::include_graphics("../inst/confusiontable.jpg")
+knitr::include_graphics("confusiontable.jpg")
 
 ## ----fft-plot, fig.width = 6.5, fig.height = 6--------------------------------
 # Plot predictions of the best FFT when applied to test data:
@@ -59,24 +59,11 @@ plot(heart.fft, what = "tree")
 plot(heart.fft, what = "cues")
 
 ## ----fft-names----------------------------------------------------------------
-# Show the names of all of the outputs in heart.fft:
+# Show the names of all outputs in heart.fft:
 names(heart.fft)
 
 ## ----fft-predict, eval = FALSE------------------------------------------------
-#  # Predict classifications for a new dataset:
-#  predict(heart.fft,
-#          newdata = heartdisease)
-
-## ----fft-my-tree, results = 'hide'--------------------------------------------
-# Create an FFT manually (from description):
-my.heart.fft <- FFTrees(formula = diagnosis ~.,
-                        data = heart.train,
-                        data.test = heart.test,
-                        main = "My Heart FFT",
-                        my.tree = "If chol > 350, predict True. 
-                                   If cp != {a}, predict False. 
-                                   If age <= 35, predict False, otherwise, predict True.")
-
-## ----plot-my-fft, fig.width = 6.5, fig.height = 6-----------------------------
-plot(my.heart.fft, data = "train")
+# # Predict classifications for a new dataset:
+# predict(heart.fft,
+#         newdata = heartdisease)
 
